@@ -7,22 +7,26 @@ class AboveTwoSMAs(Condition):
     Example condition. Checks if a stock's current price
     is above two simple moving averages (SMAs).
     """
-    def __init__(self, sma1_window: int = 150, sma2_period: int = 200) -> None:
+    def __init__(self, sma1_period: int = 150, sma2_period: int = 200) -> None:
         """
         In the constructor, implementations of this interface should be concerned with
         taking arguments defining the "rules" of the condition. In this instance, the 
         windows for computing two SMAs of the stock's close price.
         Args:
-            stock (Stock)
+            sma1_period (int)
+            sma2_period (int)
         """
         super().__init__() # Always call super
-        self.sma1_period = sma1_window
+        self.sma1_period = sma1_period
         self.sma2_period = sma2_period
 
 
     def fulfilled(self, stock: Stock) -> bool:
         """
         The method that determines whether the condition is fulfilled or not.
+        
+        Args:
+            stock (Stock)
         """
         currentClose = stock.getClose()[-1]
         SMA1 = round(stock.getClose().rolling(window=self.sma1_period).mean(), 2)
